@@ -6,7 +6,7 @@ use strict;
 use warnings;
 
 package RT::Client::REST::Forms;
-$RT::Client::REST::Forms::VERSION = '0.55';
+$RT::Client::REST::Forms::VERSION = '0.57';
 use Exporter;
 
 use vars qw(@EXPORT @ISA);
@@ -70,7 +70,7 @@ sub form_parse {
                 my $f     = $1;
                 my $value = $2;
                 my $spaces = ' ' x length($f);
-                $f =~ s/:\s$//;
+                $f =~ s/:\s?$//;
 
                 # Read continuation lines, if any.
                 while (@lines && ($lines[0] eq '' || $lines[0] =~ m/^\s+/)) {
@@ -227,7 +227,7 @@ RT::Client::REST::Forms - This package provides functions from RT::Interface::RE
 
 =head1 VERSION
 
-version 0.55
+version 0.57
 
 =head2 METHODS
 
@@ -295,7 +295,7 @@ SRVSH
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 by Dmitri Tikhonov.
+This software is copyright (c) 2020 by Dmitri Tikhonov.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
